api.currentuser package — Argus-Toolbelt 1.0 documentation

# api.currentuser package

## Subpackages

- api.currentuser.v1 package
  - Subpackages
    - api.currentuser.v1.permission package
      - Submodules
      - api.currentuser.v1.permission.permission module
      - Module contents
  - Submodules
  - api.currentuser.v1.authmethods module
  - api.currentuser.v1.functions module
  - api.currentuser.v1.picture module
  - api.currentuser.v1.prefs module
  - api.currentuser.v1.user module
  - Module contents

## Module contents